==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/options/includes/optionsflow.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012 by Eduard Kalinowski                                 *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef OPTIONSFLOW_H
#define OPTIONSFLOW_H

#include <QWidget>
#include <QString>

#include "./OptionsDialog.h"
#include "ui_OptionsFlow.h"

class OptionsDialog;

class optionsFlow : public QWidget, private Ui::flowForm
{
        Q_OBJECT

    public:
        optionsFlow(QWidget* parent = 0, Qt::WFlags fl = 0);
        ~optionsFlow();
        /*$PUBLIC_FUNCTIONS$*/
    private:
        void initTextPoints();

    public slots:
        /*$PUBLIC_SLOTS$*/

    protected:
        void selectOnCombo(QComboBox& cb, QStringList& sl, QString vari);

    protected:
        /*$PROTECTED_FUNCTIONS$*/
        OptionsDialog* parentDialog;

    protected slots:
        /*$PROTECTED_SLOTS$*/
    private:
        QVector<trWidgets>* opts;
};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/options/includes/optionsflow.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012 by Eduard Kalinowski                                 *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef OPTIONSFLOW_H
#define OPTIONSFLOW_H

#include <QWidget>
#include <QString>

#include "./OptionsDialog.h"
#include "ui_OptionsFlow.h"

class OptionsDialog;

class optionsFlow : public QWidget, private Ui::flowForm
{
        Q_OBJECT

    public:
        optionsFlow(QWidget* parent = 0, Qt::WindowFlags fl = 0);
        ~optionsFlow();
        /*$PUBLIC_FUNCTIONS$*/
    private:
        void initTextPoints();

    public slots:
        /*$PUBLIC_SLOTS$*/

    protected:
        void selectOnCombo(QComboBox& cb, QStringList& sl, QString vari);

    protected:
        /*$PROTECTED_FUNCTIONS$*/
        OptionsDialog* parent;

    protected slots:
        /*$PROTECTED_SLOTS$*/
        void editingFinished(void);

    protected slots:
        /*$PROTECTED_SLOTS$*/
    private:
        QVector<trWidgets>* opts;
};

#endif
